@@ -1,11 +1,11 @@
 use std::convert::TryInto;
 
-use clap::{App, ArgMatches};
+use clap::{ArgMatches, Command};
 use miette::Result;
 use mit_commit_message_lints::{console::style::to_be_piped, mit::Authors};
 
-pub fn app<'help>() -> App<'help> {
-    App::new("example").about("Print example mit toml file")
+pub fn app<'help>() -> Command<'help> {
+    Command::new("example").about("Print example mit toml file")
 }
 
 pub fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
