@@ -1,11 +1,11 @@
-use clap::{App, Arg, ArgMatches};
+use clap::{Arg, ArgMatches, Command};
 use miette::Result;
 use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
 
 use crate::{current_dir, get_vcs};
 
-pub fn app<'help>() -> App<'help> {
-    App::new("enabled")
+pub fn cli<'help>() -> Command<'help> {
+    Command::new("enabled")
         .arg(
             Arg::new("scope")
                 .long("scope")
